@@ -1,11 +1,11 @@
 from .toolbox import YandexTurboFeed, sanitize_turbo
 
 
-VERSION = (1, 0, 0)
+VERSION = (1, 0, 1)
 """Application version number tuple."""
 
 VERSION_STR = '.'.join(map(str, VERSION))
 """Application version number string."""
 
 
-default_app_config = 'yaturbo.config.YaturboConfig'
\ No newline at end of file
+default_app_config = 'yaturbo.apps.YaturboConfig'
\ No newline at end of file
